@@ -122,7 +122,11 @@ sdf_copy_to.pyspark_connection <- function(sc,
 
 #' @export
 tbl.pyspark_connection <- function(src, from, ...) {
-  sql_from <- as.sql(from, con = src$con)
+  if(inherits(from, "AsIs")) {
+    sql_from <- from
+  } else {
+    sql_from <- as.sql(from, con = src$con)
+  }
   con <- python_conn(src)
   pyspark_obj <- con$table(sql_from)
   vars <- as.character(pyspark_obj$columns)
@@ -170,6 +174,13 @@ tbl_temp_name <- function() glue("{temp_prefix()}{random_string()}")
 
 #' @export
 sdf_register.spark_pyobj <- function(x, name = NULL) {
+  # Attempting to cache a data frame with 0 columns returns an error.
+  # So it returns nothing when this is the case (#110)
+  if(inherits(x$pyspark_obj, "pyspark.sql.connect.dataframe.DataFrame")) {
+    if(length(x$pyspark_obj$columns) == 0) {
+      return(invisible())
+    }
+  }
   sc <- spark_connection(x)
   tbl_pyspark_temp(
     x = x$pyspark_obj,
