@@ -3,6 +3,6 @@ import rpy2.robjects as robjects
 from rpy2.robjects import pandas2ri
 def r_apply(pdf: pd.DataFrame) -> pd.DataFrame:
   pandas2ri.activate()
-  r_func =robjects.r("function(...) 1")
+  r_func =robjects.r('''function(...) 1''')
   ret = r_func(pdf)
   return pandas2ri.rpy2py_dataframe(ret)
