@@ -1,5 +1,5 @@
 test_that("Print method works", {
-  sc <- test_spark_connect()
-  test_table_mtcars()
+  sc <- use_test_spark_connect()
+  use_test_table_mtcars()
   expect_message(print(invoke(sc, "sql", "select * from mtcars limit 5")))
 })
